@@ -2,6 +2,7 @@ gets_nardl_uecm <- function(x,
                             decomp, 
                             dep_var, 
                             control = NULL, 
+                            d = Inf,
                             c_q_order = c(2), 
                             p_order = c(3), 
                             q_order = c(4),
@@ -30,13 +31,27 @@ gets_nardl_uecm <- function(x,
     n <- nrow(dx)
     cl <- ncol(dx)
     pos <- dx[, 1:cl] >= 0
+    message(ifelse(ceiling((sum(pos)/(n-1))*100) == 50, 
+                   'positive and negative change in decomp are equal.', 
+                   paste('Percentage of positive change in decomp is',
+                         ceiling((sum(pos)/(n-1))*100), 'percent while negative change is',
+                         100 - ceiling((sum(pos)/(n-1))*100))))
     dxp <- as.matrix(as.numeric(pos) * dx[, 1:cl])
     colnames(dxp) <- paste(colnames(dx), "pos", sep = "_")
     dxn <- as.matrix((1 - as.numeric(pos)) * dx[, 1:cl])
     colnames(dxn) <- paste(colnames(dx), "neg", sep = "_")
-    xp <- apply(dxp, 2, cumsum)
+    cumsum_reset <- function(threshold) {
+      function(x) {
+        accumulate(x, ~if_else(.x>=threshold, .y, .x+.y))
+      }  
+    }
+    if (d == 'mean'){
+      (d = mean(dx))
+    }
+    partial_sum <- function(x, ...) c(cumsum_reset(threshold = d[[1]])(x, ...))
+    xp <- apply(dxp, 2, partial_sum)
     colnames(xp) <- paste(colnames(x), "pos", sep = "_")
-    xn <- apply(dxn, 2, cumsum)
+    xn <- apply(dxn, 2, partial_sum)
     colnames(xn) <- paste(colnames(x), "neg", sep = "_")
     lagy <- lagm(as.matrix(y), 1)
     colnames(lagy) <- paste0(dep_var, "_1")
@@ -113,13 +128,27 @@ gets_nardl_uecm <- function(x,
     n <- nrow(dx)
     cl <- ncol(dx)
     pos <- dx[, 1:cl] >= 0
+    message(ifelse(ceiling((sum(pos)/(n-1))*100) == 50, 
+                   'positive and negative changes in decomp are equal.', 
+                   paste('Percentage of positive changes in decomp is',
+                         ceiling((sum(pos)/(n-1))*100), 'percent while negative change is',
+                         100 - ceiling((sum(pos)/(n-1))*100))))
     dxp <- as.matrix(as.numeric(pos) * dx[, 1:cl])
     colnames(dxp) <- paste(colnames(dx), "pos", sep = "_")
     dxn <- as.matrix((1 - as.numeric(pos)) * dx[, 1:cl])
     colnames(dxn) <- paste(colnames(dx), "neg", sep = "_")
-    xp <- apply(dxp, 2, cumsum)
+    cumsum_reset <- function(threshold) {
+      function(x) {
+        accumulate(x, ~if_else(.x>=threshold, .y, .x+.y))
+      }  
+    }
+    partial_sum <- function(x, ...) c(cumsum_reset(threshold = d[[1]])(x, ...))
+    if (d == 'mean'){
+      (d = mean(dx))
+    }
+    xp <- apply(dxp, 2, partial_sum)
     colnames(xp) <- paste(colnames(x), "pos", sep = "_")
-    xn <- apply(dxn, 2, cumsum)
+    xn <- apply(dxn, 2, partial_sum)
     colnames(xn) <- paste(colnames(x), "neg", sep = "_")
     lagy <- lagm(as.matrix(y), 1)
     lxp <- lagm(as.matrix(xp), 1)
@@ -434,7 +463,7 @@ pos <- str_flatten(paste(str_subset(sr_cof_nm, pattern = "_pos"), ' '))
         rownames(sr_asym_test) <- decomp
       }
       else {
-        sr_asym_test = c('This model is similar to Short-run symmetric restriction (SRSR). Thus, no need for short-run asymmetric test. See nardl_uecm_sym() for more details.')
+        sr_asym_test = c('This model is similar to Short-run symmetric restriction. Thus, no need for short-run asymmetric test. See nardl_uecm_sym() for more details.')
       }
     }
   }
